@@ -18,33 +18,33 @@
 #include "cluster.h"
 #include "ind_2.h"
 
-void clara(int *n,  /* = number of objects */
-	   int *jpp,/* = number of variables */
-	   int *kk, /* = number of clusters, 1 <= kk <= n-1 */
-	   double *x,	/* Input:  the data x[n, jpp] _rowwise_ (transposed)
-			 * Output: the first `n' values are the `clustering'
-			 *	   (integers in 1,2,..,kk) */
-	   int *nran,	/* = #{random samples} drawn	   (= `samples' in R)*/
-	   int *nsam,	/* = #{objects} drawn from data set (`sampsize' in R) */
-	   double *dys,/* [1:(1 + (nsam * (nsam - 1))/2)]
-			* Output: to contain the distances */
-	   int *mdata,	/*= {0,1}; 1: min(x) is missing value (NA);  0: no NA */
-	   double *valmd,/*[j]= missing value code (instead of NA) for x[,j]*/
-	   int *jtmd,	/* [j]= {-1,1};	 -1: x[,j] has NA; 1: no NAs in x[,j] */
-	   int *diss_kind,/*= {1,2};  1 : euclidean;  2 : manhattan*/
-	   int/*logical*/ *rng_R,/*= {0,1};  0 : use clara's internal weak RNG;
-				  *	     1 : use R's RNG (and seed) */
-	   int *nrepr,
-	   int *nsel,
-	   int *nbest,/* x[nbest[j],] : the j-th obs in the final sample */
-	   int *nr, int *nrx,/* prov. and final "medoids" aka representatives */
-	   double *radus, double *ttd, double *ratt,
-	   double *ttbes, double *rdbes, double *rabes,
-	   int *mtt, double *obj,
-	   double *avsyl, double *ttsyl, double *sylinf,
-	   int *jstop, int *trace_lev,
-	   double *tmp, /* = double [ 3 * nsam ] */
-	   int *itmp	/* = integer[ 6 * nsam ] */
+void cl_clara(int *n,  /* = number of objects */
+	      int *jpp,/* = number of variables */
+	      int *kk, /* = number of clusters, 1 <= kk <= n-1 */
+	      double *x,	/* Input:  the data x[n, jpp] _rowwise_ (transposed)
+				 * Output: the first `n' values are the `clustering'
+				 *	   (integers in 1,2,..,kk) */
+	      int *nran,	/* = #{random samples} drawn	   (= `samples' in R)*/
+	      int *nsam,	/* = #{objects} drawn from data set (`sampsize' in R) */
+	      double *dys,/* [1:(1 + (nsam * (nsam - 1))/2)]
+			   * Output: to contain the distances */
+	      int *mdata,	/*= {0,1}; 1: min(x) is missing value (NA);  0: no NA */
+	      double *valmd,/*[j]= missing value code (instead of NA) for x[,j]*/
+	      int *jtmd,	/* [j]= {-1,1};	 -1: x[,j] has NA; 1: no NAs in x[,j] */
+	      int *diss_kind,/*= {1,2};  1 : euclidean;  2 : manhattan*/
+	      int/*logical*/ *rng_R,/*= {0,1};  0 : use clara's internal weak RNG;
+				     *	     1 : use R's RNG (and seed) */
+	      int *nrepr,
+	      int *nsel,
+	      int *nbest,/* x[nbest[j],] : the j-th obs in the final sample */
+	      int *nr, int *nrx,/* prov. and final "medoids" aka representatives */
+	      double *radus, double *ttd, double *ratt,
+	      double *ttbes, double *rdbes, double *rabes,
+	      int *mtt, double *obj,
+	      double *avsyl, double *ttsyl, double *sylinf,
+	      int *jstop, int *trace_lev,
+	      double *tmp, /* = double [ 3 * nsam ] */
+	      int *itmp	/* = integer[ 6 * nsam ] */
     )
 {
 
